Django AlphaFilter 0.5beta1 — Django AlphaFilter v0.5beta1 documentation

Django AlphaFilter v0.5beta1 documentation

# Django AlphaFilter 0.5beta1

- Table of Contents
- index
  next

# Django AlphaFilter 0.5beta1

Contents:

- Installation
  - Dependencies
- Getting Started
  - Overriding the Admin Template
  - Altering Your Own Model Admin
  - Altering Another Application’s Model Admin
- The Default Alphabet
  - Changing the Default Alphabet
- The qs_alphabet_filter Template Tag
  - Requirements
  - Usage
- Reference
  - Settings

## Indices and tables

- Index
- Module Index
- Search Page